.. _cleaning:

*******************************************
Image Cleaning (:mod:`radiotools.cleaning`)
*******************************************

.. currentmodule:: radiotools.cleaning

Image cleaning module of radiotools.


Reference/API
=============

.. automodapi:: radiotools.cleaning
    :inherited-members:
